package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````'14``#0```!(@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````%'``
M`!1P```%```````!``$```#`?0``P'T!`,!]`0!\`@``K!(```8```````$`
M`@```,A]``#(?0$`R'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3`?0``P'T!`,!]`0!``@``0`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$\````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3P```%````!4````
M60```%H```!A````8@```&,`````````90```&8`````````9P```&@```!K
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````@!`````````#``<```````"``0```````P`1``$`````
M`````````!(```#F`0`````````````2````"0``````````````$0````P"
M`````````````!$```"(`0`````````````2````$```````````````$@``
M`,4!`````````````!(````8```````````````2````'P``````````````
M$@```!D"`````````````!(```#1`0`````````````2````*```````````
M````(````$T#`````````````"$```!````````````````2````1@``````
M````````$@```$T``````````````!(````:`P`````````````2````"P,`
M````````````$@```+4"`````````````!(```!4```````````````2````
M5@(`````````````$@```%L``````````````!(```#J`@`````````````2
M````8@``````````````$@```&H``````````````!(```#3`@``````````
M```2````<@``````````````$@```'L``````````````"`````$`P``````
M```````2````EP``````````````$@```)P``````````````!(````J`@``
M```````````1````\0(`````````````$@```(,"`````````````!(```"C
M```````````````2````=0(`````````````$@```)$#`````````````!(`
M``!,`P`````````````1````IP(`````````````$@```#D#````````````
M`!(````U`@`````````````2````3@,`````````````$0```*H`````````
M`````!(````Q`P`````````````2````LP``````````````$0```)8!````
M`````````!(```#%```````````````B````U```````````````(````.H`
M`````````````!(```#\`@`````````````2````DP(`````````````$@``
M`.\``````````````!(```#U```````````````@````W@(`````````````
M$@````\!`````````````!(```"V`0`````````````2````%`$`````````
M````$@```,,"`````````````!(````:`0`````````````2````I0$`````
M````````$@```"@!`````````````!(````Y`0`````````````2````40(`
M````````````$@```&("`````````````!(````_`0`````````````2````
MG`(`````````````$@```"H#`````````````!(```!.`0`````````````2
M````(@,`````````````$@```&(!`````````````!(```!,`@``````````
M```2````]`$`````````````$@```&D!`````````````!(```!P`0``````
M```````2````2P,`````````````(0```($!`````````````!(```"1!```
M;)`!```````0`!(`1@,``)T3``"``0``$@`)``8"``"=,0```@```!(`"@#3
M`P``W1\``-`$```2``D`H00```$G```X````$@`)`+`#``!Y&P``!````!(`
M"0!%!```@1````(````2``<`]@,``*TD``!4`@``$@`)`$L$```\@`$`````
M`!``$@!Y!```?1L``'`!```2``D`+@0``#R``0``````$``2`,$#``!Q'P``
M;````!(`"0#@`P``'1H``$`````2``D`Z`,``"$?``!`````$@`)``P$```A
M,```P@```!(`"0`A!```[1P``!(````2``D`.@0``&R0`0``````$``2`)P$
M``!LD`$``````!``$@!V`P``.14``$`````2``D`600``/\<``":````$@`)
M`!<$```X@`$`!````!$`$0!R!```/(`!```````0`!$`,P0``!T5````````
M$@`)`$($``#E+P``/````!(`"0!_`P``81\``!`````2``D`F@,``*4:``#4
M````$@`)`(8$``#C,```N````!(`"0"0!```;)`!```````0`!(`900``)D=
M``"(`0``$@`)``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R
M:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R
M8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E9&ER`%])
M5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C:'(`
M<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`7U]R
M96=I<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-
M0VQO;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L
M;V-A=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!P=&AR96%D7V=E='-P96-I
M9FEC`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!097)L7V-R;V%K
M7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O
M=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?86QL;V,`9G!R:6YT9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`<F5A9&1I
M<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?
M7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM87)M=C<N<V\N,0!?<W1A
M<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S96YA;64`
M7U]B<W-?<W1A<G0`7U]E;F1?7P!S:&%?:6YI=`!?7V)S<U]S=&%R=%]?`'!A
M<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?961A=&$`<&%R7V9I;F1P<F]G`'-H
M85]F:6YA;`!?7V)S<U]E;F1?7P!?96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB
M+W!E<FPU+V-O<F5?<&5R;"]#3U)%``#`?0$`%P```,1]`0`7````P'\!`!<`
M``#,?P$`%P```-A_`0`7`````(`!`!<````(@`$`%P````R``0`7````%(`!
M`!<````8@`$`%P```!R``0`7````((`!`!<````D@`$`%P```"R``0`7````
M,(`!`!<````X@`$`%P```,1_`0`5!0``R'\!`!4&``#0?P$`%0X``-1_`0`5
M'@``W'\!`!4B``#@?P$`%2P``.1_`0`5+P``Z'\!`!4Q``#L?P$`%3(``/!_
M`0`5-P``]'\!`!4\``#X?P$`%3X``/Q_`0`50@``Q'X!`!8#``#(?@$`%@0`
M`,Q^`0`6!P``T'X!`!8(``#4?@$`%@D``-A^`0`6"@``W'X!`!8+``#@?@$`
M%@P``.1^`0`6#0``Z'X!`!8.``#L?@$`%A```/!^`0`6$0``]'X!`!82``#X
M?@$`%A,``/Q^`0`6%````'\!`!85```$?P$`%A8```A_`0`6%P``#'\!`!88
M```0?P$`%AD``!1_`0`6&@``&'\!`!8;```<?P$`%AP``"!_`0`6'0``)'\!
M`!8?```H?P$`%B```"Q_`0`6(0``,'\!`!8C```T?P$`%B0``#A_`0`6)0``
M/'\!`!8F``!`?P$`%B<``$1_`0`6*0``2'\!`!8J``!,?P$`%BL``%!_`0`6
M+0``5'\!`!8N``!8?P$`%C```%Q_`0`6,0``8'\!`!8R``!D?P$`%C,``&A_
M`0`6-```;'\!`!8U``!P?P$`%C8``'1_`0`6.```>'\!`!8Y``!\?P$`%CH`
M`(!_`0`6.P``A'\!`!8]``"(?P$`%C\``(Q_`0`60```D'\!`!9!``"4?P$`
M%D,``)A_`0`61```G'\!`!9%``"@?P$`%D8``*1_`0`61P``J'\!`!9(``"L
M?P$`%DD``+!_`0`62@``M'\!`!9+``"X?P$`%DP``+Q_`0`63@```;6]Z`%`
M<$<$X"WE!."?Y0[@C^`(\+[E(&X!``#&C^(6RHSB(/Z\Y0#&C^(6RHSB&/Z\
MY0#&C^(6RHSB$/Z\Y0#&C^(6RHSB"/Z\Y0#&C^(6RHSB`/Z\Y0#&C^(6RHSB
M^/V\Y0#&C^(6RHSB\/V\Y0#&C^(6RHSBZ/V\Y0#&C^(6RHSBX/V\Y0#&C^(6
MRHSBV/V\Y0#&C^(6RHSBT/V\Y0#&C^(6RHSBR/V\Y0#&C^(6RHSBP/V\Y0#&
MC^(6RHSBN/V\Y0#&C^(6RHSBL/V\Y0#&C^(6RHSBJ/V\Y0#&C^(6RHSBH/V\
MY0#&C^(6RHSBF/V\Y0#&C^(6RHSBD/V\Y0#&C^(6RHSBB/V\Y0#&C^(6RHSB
M@/V\Y0#&C^(6RHSB>/V\Y0#&C^(6RHSB</V\Y0#&C^(6RHSB:/V\Y7A'_><`
MQH_B%LJ,XES]O.4`QH_B%LJ,XE3]O.4`QH_B%LJ,XDS]O.4`QH_B%LJ,XD3]
MO.4`QH_B%LJ,XCS]O.4`QH_B%LJ,XC3]O.4`QH_B%LJ,XBS]O.4`QH_B%LJ,
MXB3]O.4`QH_B%LJ,XAS]O.4`QH_B%LJ,XA3]O.4`QH_B%LJ,X@S]O.4`QH_B
M%LJ,X@3]O.4`QH_B%LJ,XOS\O.4`QH_B%LJ,XO3\O.4`QH_B%LJ,XNS\O.4`
MQH_B%LJ,XN3\O.4`QH_B%LJ,XMS\O.4`QH_B%LJ,XM3\O.4`QH_B%LJ,XLS\
MO.4`QH_B%LJ,XL3\O.4`QH_B%LJ,XKS\O.4`QH_B%LJ,XK3\O.4`QH_B%LJ,
MXJS\O.4`QH_B%LJ,XJ3\O.4`QH_B%LJ,XIS\O.4`QH_B%LJ,XI3\O.4`QH_B
M%LJ,XHS\O.5X1_WG`,:/XA;*C.*`_+SE`,:/XA;*C.)X_+SE>$?]YP#&C^(6
MRHSB;/R\Y0#&C^(6RHSB9/R\Y0#&C^(6RHSB7/R\Y0#&C^(6RHSB5/R\Y0#&
MC^(6RHSB3/R\Y0#&C^(6RHSB1/R\Y0#&C^(6RHSB//R\Y0#&C^(6RHSB-/R\
MY0#&C^(6RHSB+/R\Y0#&C^(6RHSB)/R\Y3"UB;#-Z080!9(&J06J!ZA*3/_W
M5N]*2WQ$XU@#DTE+`YKC6!%&&$8$D__WONY&2^-8'7A%2^18?;G_]P;O1$IZ
M1!!A$+D!(/_W3.__]V[O(&C_]Z;O@/A]5R!H__>@[Y#XSC-#\`(#@/C.,R!H
M__>8[Y#XSC-#\`$#@/C.,P>8!3"P\8!/`=/_]PCO@`#_]T+O`48&G"]+(FA[
M1`)@+DJ88'I$0F`M2GI$$FB"8"Q*>D1!^`PO!"):8`$C!YJ:0C;<`"$"\8!#
M`S,F34#X(Q``D25)?40#1@,R*&EY1/_WE.X$1ABY*&G_]PCO!$8?37U$*&G_
M]\;N'4AX1`#P&/E@N>MH([D;2'A$`/`1^>A@&4M[1-AH"+$!\"3Y%TM[1!AI
M__=0[__W^.T@1@FP,+U4^"-0`3-!^`1?P.<`:P$`1`$``$`!```0`0``)`$`
M`'AL`0`>;`$`I2```/!K`0":(```Y&L!`.$%``#(:P$`61X````>``"F:P$`
MFFL!`$_P``M/\``.`TEY1&A&(/`/#.5&`/`"^)YH`0`?M0M+"TI[1)I8`I(*
M2II8`Y(`(@&2"4J;6`(=`),!:`*;`YC_]V;N!;!=^`3[`+]V:0$`(`$```@!
M```4`0``!D@'2P=*>$1[1(-">D0#T`5+TU@#L1A'<$<`O[IJ`0"X:@$`,&D!
M`!P!```(2`E)>$1Y1`D:RP\'2@/KH0%)$'I$`]`%2]-8`[$81W!'`+^0:@$`
MCFH!`/QH`0`X`0``#DL0M7M$#DP;>'Q$H[D-2^-8([$,2WM$&&C_]SKN__>_
M_PI+XU@;L0E(>$3_]X#M`2((2WM$&G`0O0"_7&H!`-)H`0`P`0``#FH!`!@!
M```*6@``+&H!``BU!TL'2GM$FU@KL09)!TAY1'A$__<6[KWH"$"JYP"_?F@!
M`#0!``#\:0$`RED``!A++>GP1WM$BD8%1CBS%DJ;6!QH!+,#1AY&$_@!*SJY
MH49V&\A&6?@$>R>Y/$83X#TJ]=#PYS)&*48X1O_W?.T`*._1NUT]*^S1J.L$
M!*00RO@`0'0</$0@1KWH\(<$1OKG`+].:`$`*`$```>U#4H-2WI$TUAI1AMH
M`9-/\``#__>^_PE*"$MZ1--8&F@!FUI`3_```P'0__=$[@.P7?@$^P"_XF<!
M`"P!``#,9P$`<[452A5+>D336`1&&V@!DT_P``-N1A)-?40Q1B!&__>7_UBY
M#TH-2WI$TU@::`&;6D!/\``##=#_]QSN"DL`FNM8&V@#ZX(#6FA#^`0K`"KZ
MT>+G`K!PO9YG`0`L`0``C&<!`'QG`0`H`0``+>GP1S-*-$MZ1--8J+`;:">3
M3_```P5&P+$#>+.Q__>`[`9&D+$M3]_XM(#?^+20?T3X1/E$,$;_]\#L!$:(
MN3!&__?X["A&__>&[29*(DMZ1--8&F@GFUI`3_```S70__?2[1,T.48@1O_W
MHNP`*.'0048@1O_WG.P`*-O0*$;_][SM@D8@1O_WN.U01`(P__>X[()&(T8J
M1DE&__>6[6E&4$;_]U[M`3!01@O0!)L#]'!#L_6`3P71__>A_U!&__=D[;?G
M__>8[/CG*+"]Z/"'`+\P9P$`+`$``*\:``"L&@``K1H``.AF`0`0M1=*%TMZ
M1*BPTUAI1@1&&V@GDT_P``/_]TCMV+D$FP/T<$.S]8!/`M"S]2!/!M$"(2!&
M__<<[+#Z@/!`"0I*"$MZ1--8&F@GFUI`3_```P/0__=D[0`@\><HL!"]`+]&
M9@$`+`$```IF`0`MZ?!/#49*2DI+>D336(6P&V@#DT_P``,+>`9&/2L(OP$U
M*$;_]S[M`JD'1C!&__>M_M_X!)$$1OE$L+'_]S+MAT(SV`$\%?@!.P3X`3\`
M*_G1.DHW2WI$TU@::`.;6D!/\``#8=#_]R3M-4M9^`.@VO@`L%OX)#``*T/1
M,4L$\0((>T0::$_JB`@`*CS004981O_WK.O*^````"C9T-KX`#"81``C2/@$
M/`*4,T881A/X`2L*L3TJ^=$A2X`;6?@#0`(W.$3=^`B0U/@`@/_W[NM(^"D`
M`"B[T"-H`II3^"(@%O@!&Q-&$7`!,@FQ/2GWT3TB&G`5^`$K`_@!+P`J^=&F
MYP$TM><!(D!&&F#_]\[K`9``*)S064:H\0@"__?,ZP&;RO@`,+GG!;"]Z/"/
MUF4!`"P!``"H90$`BF4!`"@!``#^9@$`$[4*3`I+?$3C6!AH__>([`A+"4GC
M6'E$`9,(2P&:>T0"L+WH$$#_]VV\`+^29`$`)`$``#P!```Q&```%%4``!.U
M#$L,2GM$G%@@:/_W:.S_]];_(&C_]V3L`"('2PA)>T3-Z0`R!TIY1'I$__<R
MZP*P$+U29`$`)`$``&8:``#[%P``(PH``#"U+TDO2JWU`%V'L'E$BE@-]0!3
M%#,2:!I@3_```O_W+NLI2@.L>D0`DBA*`T9!\@$!($9Z1/_W!.M#'`_1`",C
M2"!)>$0-]0!205@4,@AH$6A(0$_P``$MT/_W0NRP]8!?`-G_W@WU@%40-2!&
M3_2`4BE&__>4ZP0>X-M@'/_W+NL#1@`HVM"H0@+2`AF50NC3JT("V2H9DT+C
MTT'R`0*40M_<(D881BE&__<"[``B`T8"5<3G&$8-]0!=![`PO01D`0`L`0``
MUA<``+P7``#,8P$`__>4ORWI\$\-1DY)K?6%74U*>42%L`1&3$B*6`WUA5-X
M1`PS$F@:8$_P``+_]Y+]+R$&1B!&__<FZYBQ1$@A1GA$__>+_D-)/TIY1`WU
MA5.*6`PS$6@::%%`3_```FK0__?4ZR!&__?,ZSM)@T9Y1"A&__>BZP=&.$O?
M^.20W_CDH'M$^43Z1`.3`"_6T#IX`"H(OT]&5K$Y1C!&__>*ZBBY,4EY1/_W
MB.L'1NWG.$;_]Z;K`"4X1,$;$/@!+2\J&-`+\0$""D2R]8!?MMH#FPWQL`BH
M\00%`)-21CM&3_2`42A&`93_]T+J`3"P]8!?`MG_W@5PW^<H1@2I__<TZZBY
M6/B0/`/T<$.S]0!/#M$!(2A&__<DZDBY%$@I1GA$__<<_BA&__>0Z@1&B^<0
M20`@>42WYR!&#?6%706PO>CPCP"_*F,!`"P!```,%P``]18``/)B`0#4%@``
MPA8``%\6``"*%P``GA8``!<6```0%@```T83^`$K`KEP1R\J"+\81O?G$+4$
M1@BQ`W@KN1](>$2]Z!!`__=4NO_W,.L!."!$A$(#1A[2&G@!."\J^-"<0AC2
M&D82^`$9+RD1T0$[G$(:1@/2$7@!.R\I^-`2&Y,<L_6`7QC8`3*R]8!?#=G_
MWA-&Y.><0NG1(W@O*P+1"$AX1,WG!TAX1,KG!TLA1GM$&$;_]VCJ$+T`(/SG
M414``.\4``!*%0``[F(!`#"U1TI'2WI$B[#36&I&1DD;:`F33_```WE$`?$*
M`P'Q*@051AAH66@(,P/%HT(J1O?1&X@]2"N`>$3_]YW\/$@\3'A$__>8_#M(
M?$1X1/_WD_PZ2'A$__>/_#E(>$3_]XO\.$AX1/_WA_PW2'A$__>#_#9(>$3_
M]W_\($;_]WS\,TAX1/_W>/PR2'A$__=T_#%(>$3_]T[\`480L2!&__=-_2Y(
M>$3_]T7\`488L2Q(>$3_]T/]*TAX1/_W._P!1JBQ*4AX1/_W.?TH22A(>41X
M1/_W,_TG2A)+>D336!IH"9M:0$_P``,8T/_W@.HB2'A$__<?_`%&$+$@2'A$
MXN<?20HB>40-\1$`__=ZZ0`HV]$<2`WQ&P%X1-3G"[`PO19A`0`L`0``GE$`
M`.X4``#M%```(Q4``.L4``#L%```ZQ0``/,4``"@%```[Q0``/44``"+%```
M[Q0``.X4``#M$P``[!0``$@4```"%0``=Q0``$)@`0#$%```9Q0``,$4``!+
M%```"+4+2WM$&V@!,PS1"4AX1/_WS/L@L0!X$+$P.!B_`2`%2WM$&&`%2WM$
M&&@(O0"_W&`!`,T3``"^8`$`N&`!``BU__<6ZO_W5ND`L0!H"+WWM19/!$9_
M1#A&__>G^R%&!48(L0-X*[D12'A$`["]Z/!`G^3_]R#IL+D@1O_W[.D&1BA&
M__?HZ3!$`C#_]^CH!D8(2PA)(D9Y1`"5>T3_]\3I,48X1N'G`[#PO?03``#@
M$P``_A(``-`3```MZ?!/W_A`%-_X0"2M]0%-B;!Y1-_X.%2*6`WU`4-(K'U$
M$FC:84_P``(<,RH=I/%T`P7Q$`ZD\5P,!D8'RH/H!P"^Z`\`K.@/`)[H`P"D
M\6@#*#6,Z`,`E>@'`(/H!P#\2/U/>$3_]T/[?T0%1M"Q`WC#L?_WCO_X2?1*
M>40-]0%#BE@<,Q%H&FA10$_P``(!T/_WBNDH1@WU`4T)L+WH\$__]YVX__=M
M_P5&F+FD\6@(6/@$"Q"YZ4U]1`O@__<7^P`H]=`#>``K\M#_]XKH!48`*.W0
M*$;_]V#I0``!,/_W8.B!1H!&W_AXHP$]^D05^`$O`"IFT:3Q7`A8^`1;A;$H
M1O_W]/H%1@`H]M`#>``K\]#_][K[`"COT"A&__=BZ`5&I/%T"D6Y6O@$B[CQ
M``]9T)CX`#``*TO1*$;_]R[I@D9(1O_W*NE01`#R!$I01O_W*.B`1L-+Q$E[
M1`"3PTLJ1GM$>43-^`20__?^Z$_TX'%`1O_WTN@!,#;1__?(Z`-H$2LQT+I*
MNTFX6`"3,FA#1@!H>43_]XKH`"6W2:I*>40-]0%#BE@<,Q%H&FA10$_P``)_
M]&RO*$8-]0%-";"]Z/"/0$911O_WT.@(\0((C>=`1O_W6?L`**700$;_]P#H
M!4:?YT5&I^=`1@2I__>BZ(%&2+&>2Z%)^%@R:$-&>40`:/_W5.C'YZ3UB'4K
M:0/T<$.S]8!/[=%4^/B\__?(Z(-%Y]$K:</S"`.S]>!_X=%01O[WMN\%1I%(
M>$3_]U;Z`"A_T3=H.$;_]Z;H`RB"1A[9C$D$.'E$.$3^]WCON+FZ\00/!-"Z
M1!KX!3PO*P_1=FANL3!&__>0Z`,H"-F"200X>40P1/[W8N\`*`B_-T;_]U;^
M@D8`*$#PH(`!1CA&_O>D[P9&`"@`\)B`3_`""4_P_S-O\!$"S?@`D"<?_O<Z
M[P8B.48P1O_W".@4^`0\`"M#T13X`SQ#*S_1%/@"/$$K.]$4^`$\0RLWT2-X
M2"LTT6-X12LQT4_P_S-O\#D",$;-^`"0_O<6[RDB.48P1O[WY.]"1EU+74E[
M1,WI`'-<2WE$>T0H1O_W'NA`1O[W_.]92"E&>$3_]]SZ*$;_]R?^*N<W:/[W
M3.\!1CA&__<E_`=&`"A_]':O<^<`(P`B`),P1@`C_O?F[@#P2_Z!1D_T`$(Y
M1C!&_O>P[P(>*-PP1J3Q1`;^]Y[OI/$P!TE&,$8`\+;^N4;?^`"Q^T0X1EE&
M%O@!*PKQ`0K^]][ONO$4#P?Q`@?RT0`C!/@(/#A+.$E[1,WI`),W2T)&>T1Y
M1*GG.49(1@#P,_[)YS-)-$AY1'A$__>&^O[WJNXQ2S))>T3-Z0`#,4M"1BA&
M>T1Y1/[WLN\N3"].+T]\1'Y$?T1/].!Q*$;^]X#O`3"&T?[W=N\#:!$K@='^
M]XKN"?$!"0"0(T9"1C%&*$;-Z0&7_O>4[^7GQEX!`"P!```$8`$`9!(``&Y>
M`0!<7@$`Y!(``+<2``!7$@``1!(``'P1```,`0``(A(``#9=`0#Q$0``6Q$`
M`.P1``#%$0``Z!$``"H1``"X#P``C@\```40``!`$0``?A```!`/``"H#P``
M.0\``!(1``!=$```X`X``-(.``!=$```]!```"WI^$^`2X%*>T2<6"!H_O=`
M[P5&(&C^]SSOE?AD,(#X93![2'A$__?[^""Q`W@Q*P'10W@+L?_W6?P@:/[W
M*.]T20LC`2)Y1/[W?.XXNR!H_O<>[W!)`R,!(GE$_O=R[@5&`"ACT2!H_O<2
M[VM)`R,!(GE$_O=F[@5&`"A\T&A(>$3_]\WX!D8`*&;0(&C^]P#O,D;K:!EH
M_O=@[FS@`27#:-_X@)&?:=_X?*'Y1-GX!#`@:*M"!?'_.`C=_O?H[@`C0D8Y
M1O[W[NT&1CBY5TY^1'-H`3N81;G1`24BX-GX"#`":%/X);"3:`KJ`P.S]8!O
M!]'1:%A&_O?"[0`HYM$!-=3G(&C^]\3N,6@"(P`B_O?6[@%&[N?^][KN.4;^
M]V[M`35S:"!HJT+UW(_G(&C^]Z[NZV@^2AEH>D3^]P[NZV@;:)MH6P*-U2!H
M_O>@[NMH&6C^][+MA>?_]TWZ!D8@:):S_O>4[NMH,D89:/[W]NTP1O[W<NX@
M:/[WBNX%1B!H_O>&[BM)`2)Y1/[W2.TI2@%&>D0H1O[WX.T@:/[W>.X`(X#X
M93`D2"5,>$3_]S?X?$3@8("YH&C_][G\X&!8N2!(>$3^]T3M_O=B[AY+>T2:
M:.MH$FA=YQQ,3_3@<7Q$X&C^]S+N$2@*T$,<`2L'V0-&H6@62.)H"6AX1/[W
M*.V]Z/B/`+\`6@$`)`$```\.``!H#P``60\``&$/``"!#0``_%H!```$(`#8
M6@$`>PX``#`.```[#@``3`P``/99`0`1#@``V%D!`,A9`0#Z#0``.+4$1O_W
M^_K_]_#Z!4;_]P?\<+%LL2-X6[$&22A&>43^]UKMA4($T2!&O>@X0/_W);@X
MO7$,```MZ?!/_4K^2WI$T[#36`&J%$8;:%&33_```P#Q7`4`\1P#4_@$&PFZ
MG4)$^`0;^-%`)!%&#6I+:P0R:T"-:`EH:T!+0$_J\W,!/--C\='I2=#I`.<!
MG0)I#430^`C`%43":,1HC.H""@KJ!PJ*Z@(*`IJ,ZK<("D0(Z@X((D0%Z_YE
MB.H,"%5$D$1/ZKX*`YJ*ZK<$+$`*1&)$A.JW!!1$!)H(Z_5HBNJU"POJ"`L*
M1(OJ"@L"Z[<"!.OX9)-$3^JX"`6:B.JU!B9`"D121(;JM0861`::"^OT:XCJ
MM`H*Z@L*"D0"Z[4"BNH("@;K^V:21$_JNPL'FHOJM`4U0`I$0D2%ZK0%%40(
MF@KK]FJ+ZK8(".H*"`I$`NNT`HCJ"P@%Z_IED$1/ZKH*"9J*ZK8)">H%"0I$
M6D2)ZK8)D40*F@CK]6B*ZK4+"^H("PI$`NNV`HOJ"@L)Z_AIDT1/ZK@("YJ(
MZK4$!.H)!`I$4D2$ZK4$%$0,F@OK^6N(ZKD*"NH+"@I$`NNU`HKJ"`H$Z_MD
MDD1/ZKL+#9J+ZKD%)4`*1$)$A>JY!15$#IH*Z_1JB^JT"`CJ"@@*1`+KN0*(
MZ@L(!>OZ99!$3^JZ"@^:BNJT!BY`"D1:1(;JM`861!":".OU:(KJM0L+Z@@+
M"D0"Z[0"B^H*"P;K^&:31$_JN`@1FHCJM00T0`I$4D2$ZK4$%$02F@OK]FN(
MZK8*"NH+"@I$!.O[9`+KM0)/ZKL+$YV*Z@@*B^JV"9)$%)H)Z@0)#40*Z_1J
M140*1(OJM`B)ZK8)J40"Z[8&:$T5F@CJ"@B(Z@L(L$16&1::">OZ:2I$3^JZ
M"@CK^6A>1(KJM`L"Z[0$BNJY`H+J"`(41!>:B^H)"U$9&)I>1`;K^&8J1$_J
MN`@$Z_9D442(ZKD*`NNY"8CJM@)B0(KJ!@J11!F:440!Z_1A*D1/ZK0$D$2$
MZK8"2D"01!J:">OQ:0+K!0L;F@OKM@N$ZK$&".OY:(;J"08J1$_JN0D41(GJ
ML0*"Z@@"%$0<FK-$*D0+Z_AK`NNQ`8GJN`*"Z@L"$40=F@3K^V0"ZP4*'II/
MZKL+*D0!Z_1ARD2+ZK@)`NNX"(OJM`)*0(GJ!`F01!^:RD0*Z_%J5AE/ZK$!
M()I>1('JM`N+Z@H+7D0"ZP4+(9H(Z_IH"^NT"X'JN@0&Z_AFA.H(!"I$3^JX
M"!%$B.JZ`G)`$40BFJ-$*D0+Z_9K`NNZ"HCJM@*"Z@L"DD0CF@'K^V$"ZP4)
M))I/ZKL+*D0*Z_%JP42+ZK8(`NNV!HOJL0*"Z@H"B.H!"!9$)9K!1`GK^FE4
M&4_JN@HFFEQ$BNJQ"XOJ"0M<1`+K!0L(X`"_F7F"6J'KV6YT5P$`+`$```;K
M^68+Z[$+BNJY`7%`BT0GF03K]F0I1$_JM@8HFHI$ANJY`0OK]&MA0"I$BD1/
MZKL%`NNY"8;JM`(*Z_MJ@NH+`D7JM`B11`CJ"@@%ZK0"*9E(Z@((ZTH)Z_II
M$40Q1$7JN@:(1`;J"08%ZKH!#D,JF0CK^6@11$_JN0D!Z[0!2>JZ!`Y$!.H(
M!`GJN@$,0RN9!NOX9A%$*41)ZK@%#$0U0`GJN`$-0RR9!.OV9!%$3^JV!@'K
MN@%&ZK@+#40+Z@0+!NJX`4OJ`0LMF07K]&411$E$1NJT"8M$">H%"0;JM`%)
MZ@$)+ID+Z_5K$41/ZK4%`>NX`47JM`J)1`KJ"PH%ZK0!2NH!"B^9">O[:1%$
M,41%ZKL&BD0&Z@D&!>J[`0Y#,)D*Z_EJ$41/ZKD)`>NT`4GJNP@.1`CJ"@@)
MZKL!2.H!"#&9!NOZ9A%$*41)ZKH%B$0U0`GJN@$-0S*9,YP11`CK]F@!Z[L!
M3^JV!D;JN@L-1!1$!>OX90;JN@%,1`OJ"`M&ZK@)2^H!"PGJ!0D&ZK@!2>H!
M"329HT0+Z_5K$41/ZK4%`>NZ`47JN`J)1`KJ"PH%ZK@!2NH!"C69">O[:1%$
M,40VGD7JNP2*1`3J"00%ZKL!%D0&Z[@&#$,*Z_EJ-$1/ZKD)-YY)ZKL(">J[
M`0CJ"@@61"Y$2.H!"+!$.)X$Z_ID2>JZ`0CK]&@)ZKH%(4`61$_JM`0I0P;K
MNP9$ZKH%,40%Z@@%!.JZ!C5#.9X!Z_AA%D1.1$3JN`DU1`GJ`0D$ZK@&2>H&
M"3J>!>OQ919$3^JQ`0;KN@9!ZK@*L40*Z@4*`>JX!DKJ!@H[G@GK]6D61#1$
M0>JU!E1$!NH)"@'JM09*Z@8*/)X$Z_ED,D0"Z[@(/9Y;2D_JN0D61#%$B>JU
M!F9`,40^GM!$%D0(Z_1H!NNU!8GJM`:&Z@@&-40_G@'K^&$61$_JN`BQ1(CJ
MM`9.0+%$0)X%Z_%E%D0&Z[0$B.JQ!FY`-$1!G@GK]6D61$_JM06P1(7JL0:&
MZ@D&L$1"G@3K^6061`;KL0&%ZKD&9D`Q1$.>".OT:!9$3^JT!#5$A.JY!H;J
M"`8U1$2>`>OX819$!NNY"83JN`9.0+%$19X%Z_%E%D1/ZK$!-$2!ZK@&;D`T
M1$:>">OU:19$!NNX"('JM0:&Z@D&L$1'G@3K^6061$_JN0DQ1(GJM09F0#%$
M2)X(Z_1H%D0&Z[4%B>JT!H;J"`8U1$F>`>OX819$3^JX"+%$B.JT!DY`L41*
MG@7K\6461`;KM`2(ZK$&;D`T1$N>">OU:19$3^JU!;!$A>JQ!H;J"0:P1$R>
M!.OY9!9$!NNQ`87JN09F0#%$39X(Z_1H%D1/ZK0$-40$X`"_W+P;C];!8LJ$
MZKD&ANH(!C5$3IX!Z_AA%D0&Z[D)A.JX!@&K3D"Q1-/X.&'3^#PQ!>OQ919$
M3^JQ`1-$-$1S1('JN`8)Z_5I;D`#Z[@(@>JU`S1$@^H)`P3K^61#1`/K]&,#
M8`SKN0.#8,-H"TH#Z[4%`VD\1!E$"4MZ1$1@Q6`!8=-8&FA1FUI`3_```P'0
M_O?8Z5.PO>CPCP"_^DX!`"P!```(M6`@_O?*Z`I*"TD"8`+QB#)"8`+Q*4*B
M]982HO:+8H)@HO&(,L)@`"+`Z002@F'"90B]`2-%9_#ATL,MZ?!!%D8%1D-I
MT@";&"B_@FE#822_`3*"88-I!?$<!P/K5G.#8<!M\+'`\4`$M$(X1*B_-$:(
M0@/2`QF90@#2_]Z(0@'K!`@!V4!%^-,B1O[W<.GK;2-$0"OK91?1*$;_]UK[
M048V&P7Q7`@_+A#<N4("V;L9F4+BT[E"`M*+&9]"W=,R1CA&_O=4Z>YEO>CP
M@;E"`=E!1=+3CT(!\4`#`=F?0LS3#$8Z1E3X!!N<0D+X!!OYT2A&__<N^T`^
M(4;4YRWI\$$!\1P'2VF.:0Q&@"&3^H/XP_/%`UH<."H%1C:Z^50'ZP(`0]T`
M(<+Q0`+^]R3H($;_]P_[."(`(3A&_O<<Z"!&Q.D5:/_W!?OC>"!&*W!CB&MP
M(V@;"JMP(VCK<.-Y*W'CB&MQ8V@;"JMQ8VCK<>-Z*W)CB6MRHV@;"JMRHVCK
M<N-[*W/CB6MSXV@;"JMSXVCK<^-\*W1CBFMT(VD;"JMT(VGK=+WH\$'^][FX
M`"'"\3@"PN<`OP&UO>@!0'!'.@```#T````*````/0````\````]````)```
M`#T````R````/0````(````]````!0```#T````3````/0````T````]````
M#````#T````C````/0```!$````]````)@```#T````!````/0```!<````]
M````"````#T````)````/0``````````````+W1M<`!005)?5$U01$E2`%1%
M35!$25(`5$U0`%5315(`55-%4DY!344`+BX`)7,O)7,`1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I
M+R5S`&5X90!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?
M1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,1%],24)205)97U!!5$@`4UE3
M5$5-`"4P,G@`)7,E<R5S)7,`<&%R+0`E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"5S.B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@
M:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`<&%R;``N<&%R`"5S)7-C
M86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6
M`!@`<&5R;`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`U,`!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE
M`"TM`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR
M97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S
M(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@
M>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I
M<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I
M;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^
M("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R
M:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=
M.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P
M+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G
M(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I
M.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@
M>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A
M<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@
M<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN
M;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P;W,["FEF
M("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E
M;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M
M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@
M)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P
M*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P*3L*<F5A9"A?1D@L("1B=68L
M("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I*3L*:68@*"AM>2`D
M:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?
M<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4[
M"GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]
M('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@
M-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T
M(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@
M)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U
M;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U
M9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@
M>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R
M;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A
M.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D:6YF;RT^>V)U9GT["G-E96LH
M)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI
M.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R
M96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO
M9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R
M="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL
M96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N
M86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS
M92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S
M=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N
M86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T
M87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%
M55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O
M8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A
M<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?
M<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@
M97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D55
M4T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H
M879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;
M,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@
M*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!
M)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/
M)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE
M(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A
M;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I
M9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@
M(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4
M)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY
M("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-
M4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN
M;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B
M.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R
M.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D
M<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I
M;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T
M:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F
M:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U
M;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&
M2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I
M.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A
M;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D
M=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C
M*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@
M(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D
M<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G
M.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O
M<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D[
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L
M<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D
M;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];
M7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B
M0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N
M="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI
M)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@
M(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT
M9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]
M('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@
M1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)&]U="D[
M"F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I
M.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO
M9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&
M:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E
M.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF
M:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII
M<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H
M($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ
M<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T
M:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E
M<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E
M<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>
M+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M
M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B
M)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E
M<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M
M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@
M>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H
M.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E
M(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR
M97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I
M<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U
M:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@
M7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$[
M"G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64[
M"FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@
M>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM0
M05)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY
M72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L
M("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q
M(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@
M)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D9&EG97-T
M(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F:"P@(CPB+"`D<')O9VYA;64I
M.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H
M*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D[
M"GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S
M=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT
M96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O
M)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@
M/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE
M(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@
M)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M
M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP
M;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U
M<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN
M960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@
M/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@
M)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D
M14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R
M;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@
M,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H
M+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M
M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#
M;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L
M:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X
M="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM0
M05)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N
M86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*
M:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*
M)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]
M+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R
M7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q
M("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`]
M(#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%
M(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R
M("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?
M)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T
M<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T
M<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%2
M7T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*`'!E<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@(``````Z````/0````H````]````#P```#T````D````/0``
M`#(````]`````@```#T````%````/0```!,````]````#0```#T````,````
M/0```",````]````$0```#T````F````/0````$````]````%P```#T````(
M````/0````D````]````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````Q%@``V14```$```!6`P```0```&$#```/````
MK00```P```"!$```#0```)TQ```9````P'T!`!L````$````&@```,1]`0`<
M````!````/7^_V\L`0``!0```-0(```&````%`(```H```#+!```"P```!``
M```5``````````,```"X?@$``@```/@!```4````$0```!<```"(#@``$0``
M`*`-```2````Z````!,````(````&`````````#[__]O`0``"/K__V\0````
M`````````````````````````````````````````````````````,A]`0``
M`````````(@0``"($```B!```(@0``"($```B!```(@0``"($```B!```(@0
M``"($```B!```(@0``"($```B!```(@0``"($```B!```(@0``"($```B!``
M`(@0``"($```B!```(@0``"($```B!```(@0``"($```B!```(@0``"($```
MB!```(@0``"($```B!```(@0``"($```B!```(@0``"($```B!```(@0``"(
M$```B!```(@0``"($```B!```(@0``"($```B!```(@0``"($```B!```(@0
M``"($```B!```(@0``"($```B!```(@0``"($```B!```)T3````````````
M`)TQ`````````````($0````````````````````````````````````````
M````````````@`$`_____S0R``!?,@```````#DR```Y,P``1#(``$LS``!,
M,@```````%`R``!5,@```````.TT``!'0T,Z("A!;'!I;F4@,3`N,BXQ7W!R
M93$I(#$P+C(N,2`R,#(P,3(P,P!!,@```&%E86)I``$H````!3<M00`&"@=!
M"`$)`@H$$@03`10!%0$7`Q@!&@(<`1X$(@$`+G-H<W1R=&%B`"YI;G1E<G``
M+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L+G!L=``N
M:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N:6YI=%]A<G)A
M>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE
M;G0`+D%232YA='1R:6)U=&5S````````````````````````````````````
M``````````````````````L````!`````@```!0!```4`0``&```````````
M`````0`````````3````]O__;P(````L`0``+`$``.@````#``````````0`
M```$````'0````L````"````%`(``!0"``#`!@``!`````,````$````$```
M`"4````#`````@```-0(``#4"```RP0``````````````0`````````M````
M"0````(```"@#0``H`T``.@````#``````````0````(````-@````D```!"
M````B`X``(@.``#X`0```P```!`````$````"````#\````!````!@```(`0
M``"`$```"````````````````@`````````Z`````0````8```"($```B!``
M`!0#``````````````0````$````10````$````&````G!,``)P3````'@``
M```````````$`````````$L````!````!@```)PQ``"<,0``"```````````
M`````@````````!1`````0````(```"D,0``I#$``&P^``````````````0`
M````````60````$````"````$'```!!P```$```````````````$````````
M`&,````.`````P```,!]`0#`?0``!```````````````!`````0```!O````
M#P````,```#$?0$`Q'T```0```````````````0````$````>P````8````#
M````R'T!`,A]``#P````!``````````$````"````(0````!`````P```+A^
M`0"X?@``2`$`````````````!`````0```")`````0````,`````@`$``(``
M`#P```````````````0`````````CP````@````#````/(`!`#R````P$```
M```````````$`````````)0````!````,``````````\@```*@``````````
M`````0````$```"=`````P``<```````````9H```#,```````````````$`
M`````````0````,``````````````)F```"M```````````````!````````
!````
